# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ytsaurus/v1/cluster_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ytsaurus/v1/cluster_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.ytsaurus.v1 import cluster_pb2 as yandex_dot_cloud_dot_ytsaurus_dot_v1_dot_cluster__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.yandex/cloud/ytsaurus/v1/cluster_service.proto\x12\x18yandex.cloud.ytsaurus.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a&yandex/cloud/ytsaurus/v1/cluster.proto\"5\n\x11GetClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"e\n\x13ListClustersRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x04 \x03(\t\"d\n\x14ListClustersResponse\x12\x33\n\x08\x63lusters\x18\x01 \x03(\x0b\x32!.yandex.cloud.ytsaurus.v1.Cluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x8c\x03\n\x14\x43reateClusterRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x15\n\x07zone_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12J\n\x04name\x18\x03 \x01(\tB<\xf2\xc7\x31\x30[a-zA-Z0-9\xd0\x81\xd1\x91\xd0\x90-\xd1\x8f]\\S{1,61}[a-zA-Z0-9\xd0\x81\xd1\x91\xd0\x90-\xd1\x8f]\x8a\xc8\x31\x04<=63\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12J\n\x06labels\x18\x05 \x03(\x0b\x32:.yandex.cloud.ytsaurus.v1.CreateClusterRequest.LabelsEntry\x12\x17\n\tsubnet_id\x18\x06 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1a\n\x12security_group_ids\x18\x07 \x03(\t\x12\x33\n\x04spec\x18\x08 \x01(\x0b\x32%.yandex.cloud.ytsaurus.v1.ClusterSpec\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15\x43reateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xeb\x02\n\x14UpdateClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12J\n\x06labels\x18\x05 \x03(\x0b\x32:.yandex.cloud.ytsaurus.v1.UpdateClusterRequest.LabelsEntry\x12\x11\n\tsubnet_id\x18\x06 \x01(\t\x12\x1a\n\x12security_group_ids\x18\x07 \x03(\t\x12\x33\n\x04spec\x18\x08 \x01(\x0b\x32%.yandex.cloud.ytsaurus.v1.ClusterSpec\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15UpdateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"8\n\x14\x44\x65leteClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x44\x65leteClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"7\n\x13StartClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"*\n\x14StartClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"6\n\x12StopClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x13StopClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t2\x83\t\n\x0e\x43lusterService\x12\x81\x01\n\x03Get\x12+.yandex.cloud.ytsaurus.v1.GetClusterRequest\x1a!.yandex.cloud.ytsaurus.v1.Cluster\"*\x82\xd3\xe4\x93\x02$\x12\"/ytsaurus/v1/clusters/{cluster_id}\x12\x84\x01\n\x04List\x12-.yandex.cloud.ytsaurus.v1.ListClustersRequest\x1a..yandex.cloud.ytsaurus.v1.ListClustersResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/ytsaurus/v1/clusters\x12\xa1\x01\n\x06\x43reate\x12..yandex.cloud.ytsaurus.v1.CreateClusterRequest\x1a!.yandex.cloud.operation.Operation\"D\xb2\xd2* \n\x15\x43reateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x1a\"\x15/ytsaurus/v1/clusters:\x01*\x12\xa1\x01\n\x06Update\x12..yandex.cloud.ytsaurus.v1.UpdateClusterRequest\x1a!.yandex.cloud.operation.Operation\"D\xb2\xd2* \n\x15UpdateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x1a\x32\x15/ytsaurus/v1/clusters:\x01*\x12\xb9\x01\n\x06\x44\x65lete\x12..yandex.cloud.ytsaurus.v1.DeleteClusterRequest\x1a!.yandex.cloud.operation.Operation\"\\\xb2\xd2*.\n\x15\x44\x65leteClusterMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02$*\"/ytsaurus/v1/clusters/{cluster_id}\x12\xb1\x01\n\x05Start\x12-.yandex.cloud.ytsaurus.v1.StartClusterRequest\x1a!.yandex.cloud.operation.Operation\"V\xb2\xd2*\x1f\n\x14StartClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02-\"(/ytsaurus/v1/clusters/{cluster_id}:start:\x01*\x12\xad\x01\n\x04Stop\x12,.yandex.cloud.ytsaurus.v1.StopClusterRequest\x1a!.yandex.cloud.operation.Operation\"T\xb2\xd2*\x1e\n\x13StopClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02,\"\'/ytsaurus/v1/clusters/{cluster_id}:stop:\x01*Be\n\x1cyandex.cloud.api.ytsaurus.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/ytsaurus/v1;ytsaurusb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ytsaurus.v1.cluster_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034yandex.cloud.api.ytsaurus.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/ytsaurus/v1;ytsaurus'
  _globals['_GETCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['zone_id']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['zone_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\362\30710[a-zA-Z0-9\320\201\321\221\320\220-\321\217]\\S{1,61}[a-zA-Z0-9\320\201\321\221\320\220-\321\217]\212\3101\004<=63'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['subnet_id']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['subnet_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STARTCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STARTCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STOPCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STOPCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CLUSTERSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002$\022\"/ytsaurus/v1/clusters/{cluster_id}'
  _globals['_CLUSTERSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\027\022\025/ytsaurus/v1/clusters'
  _globals['_CLUSTERSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateClusterMetadata\022\007Cluster\202\323\344\223\002\032\"\025/ytsaurus/v1/clusters:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateClusterMetadata\022\007Cluster\202\323\344\223\002\0322\025/ytsaurus/v1/clusters:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteClusterMetadata\022\025google.protobuf.Empty\202\323\344\223\002$*\"/ytsaurus/v1/clusters/{cluster_id}'
  _globals['_CLUSTERSERVICE'].methods_by_name['Start']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Start']._serialized_options = b'\262\322*\037\n\024StartClusterMetadata\022\007Cluster\202\323\344\223\002-\"(/ytsaurus/v1/clusters/{cluster_id}:start:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['Stop']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Stop']._serialized_options = b'\262\322*\036\n\023StopClusterMetadata\022\007Cluster\202\323\344\223\002,\"\'/ytsaurus/v1/clusters/{cluster_id}:stop:\001*'
  _globals['_GETCLUSTERREQUEST']._serialized_start=285
  _globals['_GETCLUSTERREQUEST']._serialized_end=338
  _globals['_LISTCLUSTERSREQUEST']._serialized_start=340
  _globals['_LISTCLUSTERSREQUEST']._serialized_end=441
  _globals['_LISTCLUSTERSRESPONSE']._serialized_start=443
  _globals['_LISTCLUSTERSRESPONSE']._serialized_end=543
  _globals['_CREATECLUSTERREQUEST']._serialized_start=546
  _globals['_CREATECLUSTERREQUEST']._serialized_end=942
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_start=897
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_end=942
  _globals['_CREATECLUSTERMETADATA']._serialized_start=944
  _globals['_CREATECLUSTERMETADATA']._serialized_end=987
  _globals['_UPDATECLUSTERREQUEST']._serialized_start=990
  _globals['_UPDATECLUSTERREQUEST']._serialized_end=1353
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_start=897
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_end=942
  _globals['_UPDATECLUSTERMETADATA']._serialized_start=1355
  _globals['_UPDATECLUSTERMETADATA']._serialized_end=1398
  _globals['_DELETECLUSTERREQUEST']._serialized_start=1400
  _globals['_DELETECLUSTERREQUEST']._serialized_end=1456
  _globals['_DELETECLUSTERMETADATA']._serialized_start=1458
  _globals['_DELETECLUSTERMETADATA']._serialized_end=1501
  _globals['_STARTCLUSTERREQUEST']._serialized_start=1503
  _globals['_STARTCLUSTERREQUEST']._serialized_end=1558
  _globals['_STARTCLUSTERMETADATA']._serialized_start=1560
  _globals['_STARTCLUSTERMETADATA']._serialized_end=1602
  _globals['_STOPCLUSTERREQUEST']._serialized_start=1604
  _globals['_STOPCLUSTERREQUEST']._serialized_end=1658
  _globals['_STOPCLUSTERMETADATA']._serialized_start=1660
  _globals['_STOPCLUSTERMETADATA']._serialized_end=1701
  _globals['_CLUSTERSERVICE']._serialized_start=1704
  _globals['_CLUSTERSERVICE']._serialized_end=2859
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/serverless/workflows/v1/execution.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/serverless/workflows/v1/execution.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/serverless/workflows/v1/execution.proto\x12$yandex.cloud.serverless.workflows.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\x96\x04\n\tExecution\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0bworkflow_id\x18\x02 \x01(\t\x12\x43\n\x05input\x18\x04 \x01(\x0b\x32\x34.yandex.cloud.serverless.workflows.v1.ExecutionInput\x12\x45\n\x06result\x18\x05 \x01(\x0b\x32\x35.yandex.cloud.serverless.workflows.v1.ExecutionResult\x12\x43\n\x05\x65rror\x18\x06 \x01(\x0b\x32\x34.yandex.cloud.serverless.workflows.v1.ExecutionError\x12\x46\n\x06status\x18\x07 \x01(\x0e\x32\x36.yandex.cloud.serverless.workflows.v1.Execution.Status\x12.\n\nstarted_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x08\x64uration\x18\t \x01(\x0b\x32\x19.google.protobuf.Duration\"l\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\n\n\x06QUEUED\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\n\n\x06PAUSED\x10\x03\x12\x0b\n\x07STOPPED\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\x12\x0c\n\x08\x46INISHED\x10\x06J\x04\x08\x03\x10\x04\"\xde\x01\n\x10\x45xecutionPreview\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0bworkflow_id\x18\x02 \x01(\t\x12\x46\n\x06status\x18\x04 \x01(\x0e\x32\x36.yandex.cloud.serverless.workflows.v1.Execution.Status\x12.\n\nstarted_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x08\x64uration\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationJ\x04\x08\x03\x10\x04\"5\n\x0e\x45xecutionInput\x12\x14\n\ninput_json\x18\x01 \x01(\tH\x00\x42\r\n\x05input\x12\x04\xc0\xc1\x31\x01\"8\n\x0f\x45xecutionResult\x12\x15\n\x0bresult_json\x18\x01 \x01(\tH\x00\x42\x0e\n\x06result\x12\x04\xc0\xc1\x31\x01\"5\n\x0e\x45xecutionError\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x12\n\nerror_code\x18\x02 \x01(\tB~\n(yandex.cloud.api.serverless.workflows.v1ZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/workflows/v1;workflowsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.workflows.v1.execution_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.serverless.workflows.v1ZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/workflows/v1;workflows'
  _globals['_EXECUTIONINPUT'].oneofs_by_name['input']._loaded_options = None
  _globals['_EXECUTIONINPUT'].oneofs_by_name['input']._serialized_options = b'\300\3011\001'
  _globals['_EXECUTIONRESULT'].oneofs_by_name['result']._loaded_options = None
  _globals['_EXECUTIONRESULT'].oneofs_by_name['result']._serialized_options = b'\300\3011\001'
  _globals['_EXECUTION']._serialized_start=191
  _globals['_EXECUTION']._serialized_end=725
  _globals['_EXECUTION_STATUS']._serialized_start=611
  _globals['_EXECUTION_STATUS']._serialized_end=719
  _globals['_EXECUTIONPREVIEW']._serialized_start=728
  _globals['_EXECUTIONPREVIEW']._serialized_end=950
  _globals['_EXECUTIONINPUT']._serialized_start=952
  _globals['_EXECUTIONINPUT']._serialized_end=1005
  _globals['_EXECUTIONRESULT']._serialized_start=1007
  _globals['_EXECUTIONRESULT']._serialized_end=1063
  _globals['_EXECUTIONERROR']._serialized_start=1065
  _globals['_EXECUTIONERROR']._serialized_end=1118
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Manifest(google.protobuf.message.Message):
    """Represents a streaming manifest file that defines how video content is delivered.
    Manifests contain information about available video qualities, audio tracks,
    and other metadata needed by video players to stream content efficiently.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ManifestType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ManifestTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Manifest._ManifestType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        MANIFEST_TYPE_UNSPECIFIED: Manifest._ManifestType.ValueType  # 0
        """The manifest type is not specified."""
        DASH: Manifest._ManifestType.ValueType  # 1
        """Dynamic Adaptive Streaming over HTTP (DASH) format.
        @see https://en.wikipedia.org/wiki/Dynamic_Adaptive_Streaming_over_HTTP
        """
        HLS: Manifest._ManifestType.ValueType  # 2
        """HTTP Live Streaming (HLS) format.
        @see https://en.wikipedia.org/wiki/HTTP_Live_Streaming
        """

    class ManifestType(_ManifestType, metaclass=_ManifestTypeEnumTypeWrapper):
        """Manifest format supported by the platform."""

    MANIFEST_TYPE_UNSPECIFIED: Manifest.ManifestType.ValueType  # 0
    """The manifest type is not specified."""
    DASH: Manifest.ManifestType.ValueType  # 1
    """Dynamic Adaptive Streaming over HTTP (DASH) format.
    @see https://en.wikipedia.org/wiki/Dynamic_Adaptive_Streaming_over_HTTP
    """
    HLS: Manifest.ManifestType.ValueType  # 2
    """HTTP Live Streaming (HLS) format.
    @see https://en.wikipedia.org/wiki/HTTP_Live_Streaming
    """

    URL_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    url: builtins.str
    """URL where the manifest file can be accessed."""
    type: global___Manifest.ManifestType.ValueType
    """Format of the manifest file."""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        type: global___Manifest.ManifestType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["type", b"type", "url", b"url"]) -> None: ...

global___Manifest = Manifest



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.compute.v1.instance_pb2
import yandex.cloud.compute.v1.instance_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class InstanceServiceStub:
    """A set of methods for managing Instance resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.GetInstanceRequest,
        yandex.cloud.compute.v1.instance_pb2.Instance,
    ]
    """Returns the specified Instance resource.

    To get the list of available Instance resources, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.ListInstancesRequest,
        yandex.cloud.compute.v1.instance_service_pb2.ListInstancesResponse,
    ]
    """Retrieves the list of Instance resources in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.CreateInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an instance in the specified folder.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.UpdateInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified instance."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.DeleteInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified instance."""

    UpdateMetadata: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.UpdateInstanceMetadataRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the metadata of the specified instance. For more information on metadata, see [VM metadata](/docs/compute/concepts/vm-metadata)."""

    GetSerialPortOutput: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.GetInstanceSerialPortOutputRequest,
        yandex.cloud.compute.v1.instance_service_pb2.GetInstanceSerialPortOutputResponse,
    ]
    """Returns the serial port output of the specified Instance resource."""

    Stop: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.StopInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Stops the running instance.

    You can start the instance later using the [InstanceService.Start] method.
    """

    Start: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.StartInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Starts the stopped instance."""

    Restart: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.RestartInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Restarts the running instance."""

    AttachDisk: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.AttachInstanceDiskRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Attaches the disk to the instance."""

    DetachDisk: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.DetachInstanceDiskRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Detaches the disk from the instance."""

    AttachFilesystem: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.AttachInstanceFilesystemRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Attaches the filesystem to the instance.

    The instance and the filesystem must reside in the same availability zone.

    To use the instance with an attached filesystem, the latter must be mounted.
    For details, see [documentation](/docs/compute/operations/filesystem/attach-to-vm).
    """

    DetachFilesystem: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.DetachInstanceFilesystemRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Detaches the filesystem from the instance."""

    AttachNetworkInterface: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.AttachInstanceNetworkInterfaceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Attaches the network-interface to the instance.

    To attach a network-interface, the instance must have a `STOPPED` status ([Instance.status]).
    To check the instance status, make a [InstanceService.Get] request.
    To stop the running instance, make a [InstanceService.Stop] request.
    """

    DetachNetworkInterface: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.DetachInstanceNetworkInterfaceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Detaches the network-interface to the instance.

    To Detach a network-interface, the instance must have a `STOPPED` status ([Instance.status]).
    To check the instance status, make a [InstanceService.Get] request.
    To stop the running instance, make a [InstanceService.Stop] request.
    """

    AddOneToOneNat: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.AddInstanceOneToOneNatRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Enables One-to-one NAT on the network interface."""

    RemoveOneToOneNat: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.RemoveInstanceOneToOneNatRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes One-to-one NAT from the network interface."""

    UpdateNetworkInterface: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.UpdateInstanceNetworkInterfaceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified instance network interface."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.ListInstanceOperationsRequest,
        yandex.cloud.compute.v1.instance_service_pb2.ListInstanceOperationsResponse,
    ]
    """Lists operations for the specified instance."""

    Move: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.MoveInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Moves the specified instance to another folder of the same cloud.

    The instance must be stopped before moving. To stop the instance, make a [Stop] request.

    After moving, the instance will start recording its Monitoring default metrics to its new folder. Metrics
    that have been recorded to the source folder prior to moving will be retained.
    """

    Relocate: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.RelocateInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Moves the specified instance to another availability zone

    Running instance will be restarted during this operation.
    """

    SimulateMaintenanceEvent: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.SimulateInstanceMaintenanceEventRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """maintenance"""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """access

    Lists access bindings for the instance.
    """

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the instance."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the instance."""

class InstanceServiceAsyncStub:
    """A set of methods for managing Instance resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.GetInstanceRequest,
        yandex.cloud.compute.v1.instance_pb2.Instance,
    ]
    """Returns the specified Instance resource.

    To get the list of available Instance resources, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.ListInstancesRequest,
        yandex.cloud.compute.v1.instance_service_pb2.ListInstancesResponse,
    ]
    """Retrieves the list of Instance resources in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.CreateInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an instance in the specified folder.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.UpdateInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified instance."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.DeleteInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified instance."""

    UpdateMetadata: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.UpdateInstanceMetadataRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the metadata of the specified instance. For more information on metadata, see [VM metadata](/docs/compute/concepts/vm-metadata)."""

    GetSerialPortOutput: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.GetInstanceSerialPortOutputRequest,
        yandex.cloud.compute.v1.instance_service_pb2.GetInstanceSerialPortOutputResponse,
    ]
    """Returns the serial port output of the specified Instance resource."""

    Stop: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.StopInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Stops the running instance.

    You can start the instance later using the [InstanceService.Start] method.
    """

    Start: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.StartInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Starts the stopped instance."""

    Restart: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.RestartInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Restarts the running instance."""

    AttachDisk: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.AttachInstanceDiskRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Attaches the disk to the instance."""

    DetachDisk: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.DetachInstanceDiskRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Detaches the disk from the instance."""

    AttachFilesystem: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.AttachInstanceFilesystemRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Attaches the filesystem to the instance.

    The instance and the filesystem must reside in the same availability zone.

    To use the instance with an attached filesystem, the latter must be mounted.
    For details, see [documentation](/docs/compute/operations/filesystem/attach-to-vm).
    """

    DetachFilesystem: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.DetachInstanceFilesystemRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Detaches the filesystem from the instance."""

    AttachNetworkInterface: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.AttachInstanceNetworkInterfaceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Attaches the network-interface to the instance.

    To attach a network-interface, the instance must have a `STOPPED` status ([Instance.status]).
    To check the instance status, make a [InstanceService.Get] request.
    To stop the running instance, make a [InstanceService.Stop] request.
    """

    DetachNetworkInterface: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.DetachInstanceNetworkInterfaceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Detaches the network-interface to the instance.

    To Detach a network-interface, the instance must have a `STOPPED` status ([Instance.status]).
    To check the instance status, make a [InstanceService.Get] request.
    To stop the running instance, make a [InstanceService.Stop] request.
    """

    AddOneToOneNat: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.AddInstanceOneToOneNatRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Enables One-to-one NAT on the network interface."""

    RemoveOneToOneNat: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.RemoveInstanceOneToOneNatRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes One-to-one NAT from the network interface."""

    UpdateNetworkInterface: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.UpdateInstanceNetworkInterfaceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified instance network interface."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.ListInstanceOperationsRequest,
        yandex.cloud.compute.v1.instance_service_pb2.ListInstanceOperationsResponse,
    ]
    """Lists operations for the specified instance."""

    Move: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.MoveInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Moves the specified instance to another folder of the same cloud.

    The instance must be stopped before moving. To stop the instance, make a [Stop] request.

    After moving, the instance will start recording its Monitoring default metrics to its new folder. Metrics
    that have been recorded to the source folder prior to moving will be retained.
    """

    Relocate: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.RelocateInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Moves the specified instance to another availability zone

    Running instance will be restarted during this operation.
    """

    SimulateMaintenanceEvent: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.instance_service_pb2.SimulateInstanceMaintenanceEventRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """maintenance"""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """access

    Lists access bindings for the instance.
    """

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the instance."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the instance."""

class InstanceServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Instance resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.compute.v1.instance_service_pb2.GetInstanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.instance_pb2.Instance, collections.abc.Awaitable[yandex.cloud.compute.v1.instance_pb2.Instance]]:
        """Returns the specified Instance resource.

        To get the list of available Instance resources, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.compute.v1.instance_service_pb2.ListInstancesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.instance_service_pb2.ListInstancesResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.instance_service_pb2.ListInstancesResponse]]:
        """Retrieves the list of Instance resources in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.compute.v1.instance_service_pb2.CreateInstanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates an instance in the specified folder.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.compute.v1.instance_service_pb2.UpdateInstanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified instance."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.compute.v1.instance_service_pb2.DeleteInstanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified instance."""

    @abc.abstractmethod
    def UpdateMetadata(
        self,
        request: yandex.cloud.compute.v1.instance_service_pb2.UpdateInstanceMetadataRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the metadata of the specified instance. For more information on metadata, see [VM metadata](/docs/compute/concepts/vm-metadata)."""

    @abc.abstractmethod
    def GetSerialPortOutput(
        self,
        request: yandex.cloud.compute.v1.instance_service_pb2.GetInstanceSerialPortOutputRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.instance_service_pb2.GetInstanceSerialPortOutputResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.instance_service_pb2.GetInstanceSerialPortOutputResponse]]:
        """Returns the serial port output of the specified Instance resource."""

    @abc.abstractmethod
    def Stop(
        self,
        request: yandex.cloud.compute.v1.instance_service_pb2.StopInstanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Stops the running instance.

        You can start the instance later using the [InstanceService.Start] method.
        """

    @abc.abstractmethod
    def Start(
        self,
        request: yandex.cloud.compute.v1.instance_service_pb2.StartInstanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Starts the stopped instance."""

    @abc.abstractmethod
    def Restart(
        self,
        request: yandex.cloud.compute.v1.instance_service_pb2.RestartInstanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Restarts the running instance."""

    @abc.abstractmethod
    def AttachDisk(
        self,
        request: yandex.cloud.compute.v1.instance_service_pb2.AttachInstanceDiskRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Attaches the disk to the instance."""

    @abc.abstractmethod
    def DetachDisk(
        self,
        request: yandex.cloud.compute.v1.instance_service_pb2.DetachInstanceDiskRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Detaches the disk from the instance."""

    @abc.abstractmethod
    def AttachFilesystem(
        self,
        request: yandex.cloud.compute.v1.instance_service_pb2.AttachInstanceFilesystemRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Attaches the filesystem to the instance.

        The instance and the filesystem must reside in the same availability zone.

        To use the instance with an attached filesystem, the latter must be mounted.
        For details, see [documentation](/docs/compute/operations/filesystem/attach-to-vm).
        """

    @abc.abstractmethod
    def DetachFilesystem(
        self,
        request: yandex.cloud.compute.v1.instance_service_pb2.DetachInstanceFilesystemRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Detaches the filesystem from the instance."""

    @abc.abstractmethod
    def AttachNetworkInterface(
        self,
        request: yandex.cloud.compute.v1.instance_service_pb2.AttachInstanceNetworkInterfaceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Attaches the network-interface to the instance.

        To attach a network-interface, the instance must have a `STOPPED` status ([Instance.status]).
        To check the instance status, make a [InstanceService.Get] request.
        To stop the running instance, make a [InstanceService.Stop] request.
        """

    @abc.abstractmethod
    def DetachNetworkInterface(
        self,
        request: yandex.cloud.compute.v1.instance_service_pb2.DetachInstanceNetworkInterfaceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Detaches the network-interface to the instance.

        To Detach a network-interface, the instance must have a `STOPPED` status ([Instance.status]).
        To check the instance status, make a [InstanceService.Get] request.
        To stop the running instance, make a [InstanceService.Stop] request.
        """

    @abc.abstractmethod
    def AddOneToOneNat(
        self,
        request: yandex.cloud.compute.v1.instance_service_pb2.AddInstanceOneToOneNatRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Enables One-to-one NAT on the network interface."""

    @abc.abstractmethod
    def RemoveOneToOneNat(
        self,
        request: yandex.cloud.compute.v1.instance_service_pb2.RemoveInstanceOneToOneNatRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Removes One-to-one NAT from the network interface."""

    @abc.abstractmethod
    def UpdateNetworkInterface(
        self,
        request: yandex.cloud.compute.v1.instance_service_pb2.UpdateInstanceNetworkInterfaceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified instance network interface."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.compute.v1.instance_service_pb2.ListInstanceOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.instance_service_pb2.ListInstanceOperationsResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.instance_service_pb2.ListInstanceOperationsResponse]]:
        """Lists operations for the specified instance."""

    @abc.abstractmethod
    def Move(
        self,
        request: yandex.cloud.compute.v1.instance_service_pb2.MoveInstanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Moves the specified instance to another folder of the same cloud.

        The instance must be stopped before moving. To stop the instance, make a [Stop] request.

        After moving, the instance will start recording its Monitoring default metrics to its new folder. Metrics
        that have been recorded to the source folder prior to moving will be retained.
        """

    @abc.abstractmethod
    def Relocate(
        self,
        request: yandex.cloud.compute.v1.instance_service_pb2.RelocateInstanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Moves the specified instance to another availability zone

        Running instance will be restarted during this operation.
        """

    @abc.abstractmethod
    def SimulateMaintenanceEvent(
        self,
        request: yandex.cloud.compute.v1.instance_service_pb2.SimulateInstanceMaintenanceEventRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """maintenance"""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """access

        Lists access bindings for the instance.
        """

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets access bindings for the instance."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates access bindings for the instance."""

def add_InstanceServiceServicer_to_server(servicer: InstanceServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/containerregistry/v1/lifecycle_policy_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/containerregistry/v1/lifecycle_policy_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.containerregistry.v1 import image_pb2 as yandex_dot_cloud_dot_containerregistry_dot_v1_dot_image__pb2
from yandex.cloud.containerregistry.v1 import lifecycle_policy_pb2 as yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@yandex/cloud/containerregistry/v1/lifecycle_policy_service.proto\x12!yandex.cloud.containerregistry.v1\x1a yandex/cloud/api/operation.proto\x1a-yandex/cloud/containerregistry/v1/image.proto\x1a\x38yandex/cloud/containerregistry/v1/lifecycle_policy.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/api/annotations.proto\"F\n\x19GetLifecyclePolicyRequest\x12)\n\x13lifecycle_policy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xe5\x01\n\x1cListLifecyclePoliciesRequest\x12\x1f\n\x0bregistry_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12!\n\rrepository_id\x18\x06 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100B\n\n\x02id\x12\x04\xc0\xc1\x31\x01\"\x88\x01\n\x1dListLifecyclePoliciesResponse\x12N\n\x12lifecycle_policies\x18\x01 \x03(\x0b\x32\x32.yandex.cloud.containerregistry.v1.LifecyclePolicy\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xa6\x02\n\x1c\x43reateLifecyclePolicyRequest\x12#\n\rrepository_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12O\n\x06status\x18\x04 \x01(\x0e\x32\x39.yandex.cloud.containerregistry.v1.LifecyclePolicy.StatusB\x04\xe8\xc7\x31\x01\x12?\n\x05rules\x18\x05 \x03(\x0b\x32\x30.yandex.cloud.containerregistry.v1.LifecycleRule\"\xdd\x02\n\x1cUpdateLifecyclePolicyRequest\x12)\n\x13lifecycle_policy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12O\n\x06status\x18\x05 \x01(\x0e\x32\x39.yandex.cloud.containerregistry.v1.LifecyclePolicy.StatusB\x04\xe8\xc7\x31\x01\x12?\n\x05rules\x18\x06 \x03(\x0b\x32\x30.yandex.cloud.containerregistry.v1.LifecycleRule\"I\n\x1c\x44\x65leteLifecyclePolicyRequest\x12)\n\x13lifecycle_policy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"<\n\x1d\x43reateLifecyclePolicyMetadata\x12\x1b\n\x13lifecycle_policy_id\x18\x01 \x01(\t\"<\n\x1dUpdateLifecyclePolicyMetadata\x12\x1b\n\x13lifecycle_policy_id\x18\x01 \x01(\t\"<\n\x1d\x44\x65leteLifecyclePolicyMetadata\x12\x1b\n\x13lifecycle_policy_id\x18\x01 \x01(\t\"I\n\x1c\x44ryRunLifecyclePolicyRequest\x12)\n\x13lifecycle_policy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"h\n\x1d\x44ryRunLifecyclePolicyMetadata\x12*\n\"dry_run_lifecycle_policy_result_id\x18\x01 \x01(\t\x12\x1b\n\x13lifecycle_policy_id\x18\x02 \x01(\t\"\xb1\x01\n\x1b\x44ryRunLifecyclePolicyResult\x12*\n\"dry_run_lifecycle_policy_result_id\x18\x01 \x01(\t\x12\x1b\n\x13lifecycle_policy_id\x18\x02 \x01(\t\x12*\n\x06run_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1d\n\x15\x61\x66\x66\x65\x63ted_images_count\x18\x04 \x01(\x03\"a\n%GetDryRunLifecyclePolicyResultRequest\x12\x38\n\"dry_run_lifecycle_policy_result_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xcb\x01\n\'ListDryRunLifecyclePolicyResultsRequest\x12)\n\x13lifecycle_policy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\xad\x01\n(ListDryRunLifecyclePolicyResultsResponse\x12h\n dry_run_lifecycle_policy_results\x18\x01 \x03(\x0b\x32>.yandex.cloud.containerregistry.v1.DryRunLifecyclePolicyResult\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xe7\x01\n4ListDryRunLifecyclePolicyResultAffectedImagesRequest\x12\x38\n\"dry_run_lifecycle_policy_result_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x93\x01\n5ListDryRunLifecyclePolicyResultAffectedImagesResponse\x12\x41\n\x0f\x61\x66\x66\x65\x63ted_images\x18\x01 \x03(\x0b\x32(.yandex.cloud.containerregistry.v1.Image\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x82\x11\n\x16LifecyclePolicyService\x12\xbf\x01\n\x03Get\x12<.yandex.cloud.containerregistry.v1.GetLifecyclePolicyRequest\x1a\x32.yandex.cloud.containerregistry.v1.LifecyclePolicy\"F\x82\xd3\xe4\x93\x02@\x12>/container-registry/v1/lifecyclePolicies/{lifecycle_policy_id}\x12\xbb\x01\n\x04List\x12?.yandex.cloud.containerregistry.v1.ListLifecyclePoliciesRequest\x1a@.yandex.cloud.containerregistry.v1.ListLifecyclePoliciesResponse\"0\x82\xd3\xe4\x93\x02*\x12(/container-registry/v1/lifecyclePolicies\x12\xd5\x01\n\x06\x43reate\x12?.yandex.cloud.containerregistry.v1.CreateLifecyclePolicyRequest\x1a!.yandex.cloud.operation.Operation\"g\xb2\xd2*0\n\x1d\x43reateLifecyclePolicyMetadata\x12\x0fLifecyclePolicy\x82\xd3\xe4\x93\x02-\"(/container-registry/v1/lifecyclePolicies:\x01*\x12\xeb\x01\n\x06Update\x12?.yandex.cloud.containerregistry.v1.UpdateLifecyclePolicyRequest\x1a!.yandex.cloud.operation.Operation\"}\xb2\xd2*0\n\x1dUpdateLifecyclePolicyMetadata\x12\x0fLifecyclePolicy\x82\xd3\xe4\x93\x02\x43\x32>/container-registry/v1/lifecyclePolicies/{lifecycle_policy_id}:\x01*\x12\xef\x01\n\x06\x44\x65lete\x12?.yandex.cloud.containerregistry.v1.DeleteLifecyclePolicyRequest\x1a!.yandex.cloud.operation.Operation\"\x80\x01\xb2\xd2*6\n\x1d\x44\x65leteLifecyclePolicyMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02@*>/container-registry/v1/lifecyclePolicies/{lifecycle_policy_id}\x12\xfc\x01\n\x06\x44ryRun\x12?.yandex.cloud.containerregistry.v1.DryRunLifecyclePolicyRequest\x1a!.yandex.cloud.operation.Operation\"\x8d\x01\xb2\xd2*<\n\x1d\x44ryRunLifecyclePolicyMetadata\x12\x1b\x44ryRunLifecyclePolicyResult\x82\xd3\xe4\x93\x02G\"B/container-registry/v1/dryRunLifecyclePolicy/{lifecycle_policy_id}:\x01*\x12\xfd\x01\n\x0fGetDryRunResult\x12H.yandex.cloud.containerregistry.v1.GetDryRunLifecyclePolicyResultRequest\x1a>.yandex.cloud.containerregistry.v1.DryRunLifecyclePolicyResult\"`\x82\xd3\xe4\x93\x02Z\x12X/container-registry/v1/dryRunLifecyclePolicyResults/{dry_run_lifecycle_policy_result_id}\x12\xe9\x01\n\x11ListDryRunResults\x12J.yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultsRequest\x1aK.yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultsResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/container-registry/v1/dryRunLifecyclePolicyResults\x12\xc4\x02\n\x1eListDryRunResultAffectedImages\x12W.yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultAffectedImagesRequest\x1aX.yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultAffectedImagesResponse\"o\x82\xd3\xe4\x93\x02i\x12g/container-registry/v1/dryRunLifecyclePolicyResults/{dry_run_lifecycle_policy_result_id}:affectedImagesB\x80\x01\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistry'
  _globals['_GETLIFECYCLEPOLICYREQUEST'].fields_by_name['lifecycle_policy_id']._loaded_options = None
  _globals['_GETLIFECYCLEPOLICYREQUEST'].fields_by_name['lifecycle_policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTLIFECYCLEPOLICIESREQUEST'].oneofs_by_name['id']._loaded_options = None
  _globals['_LISTLIFECYCLEPOLICIESREQUEST'].oneofs_by_name['id']._serialized_options = b'\300\3011\001'
  _globals['_LISTLIFECYCLEPOLICIESREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_LISTLIFECYCLEPOLICIESREQUEST'].fields_by_name['registry_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTLIFECYCLEPOLICIESREQUEST'].fields_by_name['repository_id']._loaded_options = None
  _globals['_LISTLIFECYCLEPOLICIESREQUEST'].fields_by_name['repository_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTLIFECYCLEPOLICIESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTLIFECYCLEPOLICIESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTLIFECYCLEPOLICIESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTLIFECYCLEPOLICIESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTLIFECYCLEPOLICIESREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTLIFECYCLEPOLICIESREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTLIFECYCLEPOLICIESREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTLIFECYCLEPOLICIESREQUEST'].fields_by_name['order_by']._serialized_options = b'\212\3101\005<=100'
  _globals['_CREATELIFECYCLEPOLICYREQUEST'].fields_by_name['repository_id']._loaded_options = None
  _globals['_CREATELIFECYCLEPOLICYREQUEST'].fields_by_name['repository_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATELIFECYCLEPOLICYREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATELIFECYCLEPOLICYREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _globals['_CREATELIFECYCLEPOLICYREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATELIFECYCLEPOLICYREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATELIFECYCLEPOLICYREQUEST'].fields_by_name['status']._loaded_options = None
  _globals['_CREATELIFECYCLEPOLICYREQUEST'].fields_by_name['status']._serialized_options = b'\350\3071\001'
  _globals['_UPDATELIFECYCLEPOLICYREQUEST'].fields_by_name['lifecycle_policy_id']._loaded_options = None
  _globals['_UPDATELIFECYCLEPOLICYREQUEST'].fields_by_name['lifecycle_policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATELIFECYCLEPOLICYREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATELIFECYCLEPOLICYREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _globals['_UPDATELIFECYCLEPOLICYREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATELIFECYCLEPOLICYREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATELIFECYCLEPOLICYREQUEST'].fields_by_name['status']._loaded_options = None
  _globals['_UPDATELIFECYCLEPOLICYREQUEST'].fields_by_name['status']._serialized_options = b'\350\3071\001'
  _globals['_DELETELIFECYCLEPOLICYREQUEST'].fields_by_name['lifecycle_policy_id']._loaded_options = None
  _globals['_DELETELIFECYCLEPOLICYREQUEST'].fields_by_name['lifecycle_policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DRYRUNLIFECYCLEPOLICYREQUEST'].fields_by_name['lifecycle_policy_id']._loaded_options = None
  _globals['_DRYRUNLIFECYCLEPOLICYREQUEST'].fields_by_name['lifecycle_policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETDRYRUNLIFECYCLEPOLICYRESULTREQUEST'].fields_by_name['dry_run_lifecycle_policy_result_id']._loaded_options = None
  _globals['_GETDRYRUNLIFECYCLEPOLICYRESULTREQUEST'].fields_by_name['dry_run_lifecycle_policy_result_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST'].fields_by_name['lifecycle_policy_id']._loaded_options = None
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST'].fields_by_name['lifecycle_policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST'].fields_by_name['order_by']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST'].fields_by_name['dry_run_lifecycle_policy_result_id']._loaded_options = None
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST'].fields_by_name['dry_run_lifecycle_policy_result_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST'].fields_by_name['order_by']._serialized_options = b'\212\3101\005<=100'
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002@\022>/container-registry/v1/lifecyclePolicies/{lifecycle_policy_id}'
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002*\022(/container-registry/v1/lifecyclePolicies'
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*0\n\035CreateLifecyclePolicyMetadata\022\017LifecyclePolicy\202\323\344\223\002-\"(/container-registry/v1/lifecyclePolicies:\001*'
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*0\n\035UpdateLifecyclePolicyMetadata\022\017LifecyclePolicy\202\323\344\223\002C2>/container-registry/v1/lifecyclePolicies/{lifecycle_policy_id}:\001*'
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*6\n\035DeleteLifecyclePolicyMetadata\022\025google.protobuf.Empty\202\323\344\223\002@*>/container-registry/v1/lifecyclePolicies/{lifecycle_policy_id}'
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['DryRun']._loaded_options = None
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['DryRun']._serialized_options = b'\262\322*<\n\035DryRunLifecyclePolicyMetadata\022\033DryRunLifecyclePolicyResult\202\323\344\223\002G\"B/container-registry/v1/dryRunLifecyclePolicy/{lifecycle_policy_id}:\001*'
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['GetDryRunResult']._loaded_options = None
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['GetDryRunResult']._serialized_options = b'\202\323\344\223\002Z\022X/container-registry/v1/dryRunLifecyclePolicyResults/{dry_run_lifecycle_policy_result_id}'
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['ListDryRunResults']._loaded_options = None
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['ListDryRunResults']._serialized_options = b'\202\323\344\223\0025\0223/container-registry/v1/dryRunLifecyclePolicyResults'
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['ListDryRunResultAffectedImages']._loaded_options = None
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['ListDryRunResultAffectedImages']._serialized_options = b'\202\323\344\223\002i\022g/container-registry/v1/dryRunLifecyclePolicyResults/{dry_run_lifecycle_policy_result_id}:affectedImages'
  _globals['_GETLIFECYCLEPOLICYREQUEST']._serialized_start=410
  _globals['_GETLIFECYCLEPOLICYREQUEST']._serialized_end=480
  _globals['_LISTLIFECYCLEPOLICIESREQUEST']._serialized_start=483
  _globals['_LISTLIFECYCLEPOLICIESREQUEST']._serialized_end=712
  _globals['_LISTLIFECYCLEPOLICIESRESPONSE']._serialized_start=715
  _globals['_LISTLIFECYCLEPOLICIESRESPONSE']._serialized_end=851
  _globals['_CREATELIFECYCLEPOLICYREQUEST']._serialized_start=854
  _globals['_CREATELIFECYCLEPOLICYREQUEST']._serialized_end=1148
  _globals['_UPDATELIFECYCLEPOLICYREQUEST']._serialized_start=1151
  _globals['_UPDATELIFECYCLEPOLICYREQUEST']._serialized_end=1500
  _globals['_DELETELIFECYCLEPOLICYREQUEST']._serialized_start=1502
  _globals['_DELETELIFECYCLEPOLICYREQUEST']._serialized_end=1575
  _globals['_CREATELIFECYCLEPOLICYMETADATA']._serialized_start=1577
  _globals['_CREATELIFECYCLEPOLICYMETADATA']._serialized_end=1637
  _globals['_UPDATELIFECYCLEPOLICYMETADATA']._serialized_start=1639
  _globals['_UPDATELIFECYCLEPOLICYMETADATA']._serialized_end=1699
  _globals['_DELETELIFECYCLEPOLICYMETADATA']._serialized_start=1701
  _globals['_DELETELIFECYCLEPOLICYMETADATA']._serialized_end=1761
  _globals['_DRYRUNLIFECYCLEPOLICYREQUEST']._serialized_start=1763
  _globals['_DRYRUNLIFECYCLEPOLICYREQUEST']._serialized_end=1836
  _globals['_DRYRUNLIFECYCLEPOLICYMETADATA']._serialized_start=1838
  _globals['_DRYRUNLIFECYCLEPOLICYMETADATA']._serialized_end=1942
  _globals['_DRYRUNLIFECYCLEPOLICYRESULT']._serialized_start=1945
  _globals['_DRYRUNLIFECYCLEPOLICYRESULT']._serialized_end=2122
  _globals['_GETDRYRUNLIFECYCLEPOLICYRESULTREQUEST']._serialized_start=2124
  _globals['_GETDRYRUNLIFECYCLEPOLICYRESULTREQUEST']._serialized_end=2221
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST']._serialized_start=2224
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST']._serialized_end=2427
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTSRESPONSE']._serialized_start=2430
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTSRESPONSE']._serialized_end=2603
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST']._serialized_start=2606
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST']._serialized_end=2837
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESRESPONSE']._serialized_start=2840
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESRESPONSE']._serialized_end=2987
  _globals['_LIFECYCLEPOLICYSERVICE']._serialized_start=2990
  _globals['_LIFECYCLEPOLICYSERVICE']._serialized_end=5168
# @@protoc_insertion_point(module_scope)
